@@ -1,16 +1,13 @@
 package Dist::Zilla::Plugin::HelpWanted;
-BEGIN {
-  $Dist::Zilla::Plugin::HelpWanted::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $Dist::Zilla::Plugin::HelpWanted::VERSION = '0.3.1';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: insert 'Help Wanted' information in the distribution's META
+$Dist::Zilla::Plugin::HelpWanted::VERSION = '0.3.2';
 
-
-use strict;
+use 5.34.0;
 use warnings;
 
+use experimental qw/ signatures /;
+
 use Moose;
 use List::MoreUtils qw(uniq);
 
@@ -43,18 +40,17 @@ has [ @positions ] => (
     default => 0,
 );
 
-has 'positions' => (
+has positions => (
     is      => 'ro',
     isa     => 'Str',
     default => '',
 );
 
-sub setup_installer {
-    my $self = shift;
+sub setup_installer($self) {
 
     for my $p ( split ' ', $self->positions ) {
-        eval { $self->$p(1) } or
-            die "position '$p' not recognized\n";
+        eval { $self->$p(1); 1; }
+            or die "position '$p' not recognized\n";
     }
 
     my @open_positions =
@@ -62,9 +58,8 @@ sub setup_installer {
         map { exists($legacy{$_}) ? $legacy{$_} : $_ }
         grep { $self->$_ } @positions;
 
-    @open_positions or return;
-
-    $self->zilla->distmeta->{x_help_wanted} = \@open_positions;
+    $self->zilla->distmeta->{x_help_wanted} = \@open_positions
+        if @open_positions;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -75,13 +70,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::HelpWanted - insert 'Help Wanted' information in the distribution's META
 
 =head1 VERSION
 
-version 0.3.1
+version 0.3.2
 
 =head1 SYNOPSIS
 
@@ -130,23 +127,13 @@ L<DOAP|https://github.com/edumbill/doap/wiki>) is:
 
 =back
 
-=head1 SEE ALSO
-
-=over
-
-=item OpenHatch (L<http://openhatch.org/>) 
-
-A non-profit site dedicated to matching prospective free software contributors with communities, tools, and education. 
-
-=back
-
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Yanick Champoux.
+This software is copyright (c) 2025 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
